@@ -10,7 +10,7 @@ from flask_restplus import Api as ApiRestplus
 from jsonschema import FormatChecker
 
 load_dotenv()
-database = None
+database = SQLAlchemy()
 flask_bcrypt = None
 config = {}
 
@@ -25,7 +25,7 @@ class Api():
         #super(ApiRestplus, self).__init__()
         
         self.app = Flask(name, template_folder='templates')
-        self.db = SQLAlchemy()
+        self.db = database
         self.flask_bcrypt = Bcrypt()
         self.app_config = app_config
         self.api = ApiRestplus(self.app,
